tuplettools.fix_contents_of_tuplets_in_expr
===========================================

.. autofunction:: abjad.tools.tuplettools.fix_contents_of_tuplets_in_expr.fix_contents_of_tuplets_in_expr
   :noindex:
